Analytically computes all possible table splits and summarizes their statistics.
Source:R/sp_var_to_merge.R
explore_reduce_dims.RdAnalytically computes all possible table splits and summarizes their statistics.
R/sp_var_to_merge.R
explore_reduce_dims.RdAnalytically computes all possible table splits and summarizes their statistics.